//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                       (c) 1997 European Space Agency
//
//---------------------------------------------------------------------------
//
//	ImageDisplayer.h:	--- abstract class for image displayer
//
//	DESCRIPTION:
//		A class `ImageDisplayer' is defined which provides a set of functions
//		to control the display of a 2-D image via an external display
//		program.
//
//	CHANGE HISTORY:
//		UL, 1998-10-20: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Tue Oct 20 15:23:28 MET DST 1998
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/imgdisplay/src/ImageDisplayer.h,v 1.4 2000/01/19 16:19:32 ulammers Exp $
//

#ifndef IMAGE_DISPLAYER_H
#define IMAGE_DISPLAYER_H

#include <string>
#include <vector>
#include "Tracer.h"

class ImageDisplayer {
public:
	ImageDisplayer() { PROC ENDPROC }
		//
		//	PURPOSE:
		//		Create instance of image displayer
		//

	virtual bool isUp() const = 0;
	virtual bool isDown() const { PROC RETURN !isUp(); }
		//
		//	RETURNS:
		//		T/F: Image displayer is up/not up
		//

	virtual void flipX() const = 0;
	virtual void flipY() const = 0;
		//
		//	PURPOSE:
		//		Flip displayed image around X/Y axis
		//

	typedef enum { X1, X2, X4 } ZoomFactor;
	virtual void zoomIn(ZoomFactor zoomFactor = X1) const = 0;
	virtual void zoomOut(ZoomFactor zoomFactor = X1) const = 0;
		//
		//	PURPOSE:
		//		Zoom in/out by the specified factor
		//

	virtual void displayImage(const string &dataSetName) const = 0;
		//
		//	PURPOSE:
		//		Load a new image into the image display frame thereby
		//		destroying the currently displayed one (if any)
		//


	virtual void displayRegion(const string &regionTable) const = 0;
		//
		//	PURPOSE:
		//		Visualize the contents of an ASC-region file by
		//		overlaying the currently displayed image with
		//		region markers
		//
		//	ARGUMENTS:
		//		regionTable: name of ASC-region table to visualize
		//


	virtual vector<string> regionSelection() const = 0;
		//
		//	PURPOSE:
		//		Return active region selections in the image display frame
		//		in a string representation
		//

	virtual void down() const = 0;
		//
		//	PURPOSE:
		//		Bring the image display program down.
		//


	virtual vector<string> receive(const string &command) const = 0;
	virtual void send(const string &command) const = 0;
		//
		//	PURPOSE:
		//		Send an arbitray command to the image displayer and
		//		collect the response; return in a vector of strings
		//


	virtual ~ImageDisplayer() {}
		//
		//	PURPOSE:
		//		Destroy ImageDisplayer object
}; // ImageDisplayer

#endif



