//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                       (c) 1997 European Space Agency
//
//---------------------------------------------------------------------------
//
//	SAOtng.h:	--- wrapper class around SAOtng
//
//	DESCRIPTION:
//		A class `SAOtng' is defined which implements the `ImageDisplayer'
//		interface using the image display program SAOtng.
//
//	CHANGE HISTORY:
//		UL, 1998-10-20: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Tue Oct 20 15:23:28 MET DST 1998
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/imgdisplay/src/SAOtng.h,v 1.6 2000/07/20 16:22:01 ulammers Exp $
//

#ifndef SAOTNG_H
#define SAOTNG_H

#include "ImageDisplayer.h"

class SAOtng : public virtual ImageDisplayer {
public:
	SAOtng(const string &name = "saotng");

	bool isUp() const { PROC RETURN isRunning(); }

	void flipX() const;
	void flipY() const;

	void zoomIn(ZoomFactor zoomFactor = X1) const;
	void zoomOut(ZoomFactor zoomFactor = X1) const;

	void displayImage(const string &dataSetName) const;
	void displayRegion(const string &regionTable) const;
	vector<string> regionSelection() const;

	void send(const string &command) const;

	vector<string> receive(const string &command) const;

	void down() const;

	~SAOtng();

private:
	static const string Xpaset;	//	send commands to SAOtng
	static const string Xpaget;	//	read settings from SAOtng
	static const string TITENV;	//	"SAOtng-$LOGNAME"

	//	methods
	bool isRunning() const;
		//	Is SAOtng running?

	bool isThere() const;
		//	Is the executable there?

	void execBackground(const string &command) const;
		//	execute command in the background

	//	data members
	string	_title;	//	window title of SAOtng
	string	_Saotng; //	name of the game
}; // SAOtng;

#endif

