//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	imgdisplay.cc --- the imgdisplayer task
//
//	DESCRIPTION:
//		`imgdisplay' is used to display images in datasets using SAOtng.
//
//	CHANGE HISTORY:
//		UL, 1998-10-20: 0.1.0: - initial version
//		UL, 1999-02-11: 1.0.0: - added include statement enforced by
//								 taskmain >v1.17
//		UL, 1999-11-01: 1.1.0: - added "send"/"receive" command line arguments
//		UL, 2000-01-19: 1.2.0: - added support for two now parameters:
//								    withregiontable
//									regiontable
//
//	AUTHOR:
//		U. Lammers (UL), Tue Oct 20 15:42:15 MET DST 1998
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/imgdisplay/src/imgdisplay.cc,v 1.11 2000/07/20 16:22:01 ulammers Exp $
//

#include <iostream>
#include <string>

#include "param.h"
#include "errstr.h"
#include "SAOtng.h"
#include "Ds9.h"
#include "stringutil.h"

#include "imgdisplay.h"

const string IMGVIEWER = "SAS_IMAGEVIEWER";		//	name of env variable

void imgdisplay()
{
	PROC

	if (booleanParameter("startviewer")) {
		ImageDisplayer *viewer;
		//
		//	figure which image viewer to use
		//
		string displ(stringParameter("viewer"));
		if (displ == "ENV") {
			//
			//	no viewer specified as task parameter - get value
			//	from environment
			//
			char *p = getenv(IMGVIEWER.c_str());
			if (p)
				displ = p;
			else
				errstr<<"No image viewer specified via task parameter "
						"`viewer\' and environment variable `"
					  <<IMGVIEWER<<"\' not set either - cannot continue"
					  <<Sas::error("NoImageViewerSpecified");
		}
		//
		//	now instantiate the right viewer
		//
		string viewerstr(lowercase(displ));
		if (viewerstr.find("saotng") != string::npos)
			viewer = new SAOtng(displ);
		else
			viewer = new Ds9(displ);

		if (viewer->isUp()) {
			if (booleanParameter("withimagefile"))
				viewer->displayImage(stringParameter("imagefile"));
			if (booleanParameter("flipx"))
				viewer->flipX();
			if (booleanParameter("flipy"))
				viewer->flipY();
			if (booleanParameter("withregion")) {
				setParameter("regions", viewer->regionSelection());
			}
			if (booleanParameter("withregiontable"))
				viewer->displayRegion(stringParameter("regiontable"));

			//	process additional commands
			if (booleanParameter("withcommands")) {
				vector<string> commands(stringListParameter("commands"));
				for (unsigned n=0; n<commands.size(); ++n)
					viewer->send(commands[n]);
			}
			if (booleanParameter("withreceive")) {
				vector<string> commands(stringListParameter("commands")),
							   reply;
				for (unsigned n=0; n<commands.size(); ++n) {
					vector<string> sv = viewer->receive(commands[n]);
					for (unsigned i=0; i<sv.size(); reply.push_back(sv[i++]));
				}
				setParameter("receive", reply);
			}

			if (booleanParameter("stopviewer"))
				viewer->down();
		}
	}

	ENDPROC
}
