//
//	region.cc: See if a Ds9 region file can be converted into a CXC-Region and
//			   back to a region file
//
#include <cassert>
#include <vector>
#include <string>
#include <iostream>

#include "Ds9.h"
#include "Region.h"
#include "ASCregion.h"
#include "Evaluator.h"

int main()
{
	vector<string>	v;
	v.push_back("# Region file format: DS9 version 3.0");
	v.push_back("global color=green font=\"helvetica 10 normal\" edit=1 move=1 delete=1 include=1 fixed=0");
	v.push_back("image;circle(218,300,35)");
	v.push_back("image;-circle(339,288,34) # color=white font=\"courier 10 normal\" text={This is a circle}");
	v.push_back("image;point(342,417) # point=circle color=white");
	v.push_back("image;ellipse(194,413,70,26,0) # color=white");
	v.push_back("image;box(443.25,393.75,51.5,95.5,0) # color=magenta");
	v.push_back("image;polygon(111.89337,222.10663,190.10663,222.10663,190.10663,143.89337,111.89337,143.89337) # color=red text=\"hi there\"");
	v.push_back("image;point(122,470) # point=x color=white");

	OutASCregionTable   outtable("region.fits");
	GeoRegion	r = Ds9::toRegion(v, "red");
	outtable << r;

	for (unsigned i=0; i<r.size(); ++i) {
		Component &c = r[i];
		for (unsigned n=0; n<c.size(); ++n) {
			cout<<c[n]->name()<<" : "<<c[n]->toSelectExpression("X", "Y")
				<<endl;
			assert(Evaluator::isValidExpression(c[n]->
											toSelectExpression("X", "Y")));
		}
	}

	cout<<Ds9::Ds9Region(r); // write out region in ds9 region format

	r.free();

	return 0;
}


